@@ -1,6 +1,6 @@
 from aishu import setting
 from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port, DataManage
-from aishu.datafaker.profession.entity import zx,testMail
+from aishu.datafaker.profession.entity import zx,testMail, arPort
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
 from aishu.datafaker.profession.entity import CreateTestPort
@@ -76,14 +76,14 @@ def filed(key,inquire=[]):
         'InspectionTaskID': zx.search().createInspectionTaskID,
         'ExportFileID': zx.search().createExportFileID,
         'RepeatInspectionName': zx.search().getRepeatInspectionName,
-        'agentDeployIp':ip.date().getAentHostIp,
-        'http_port':CreateTestPort.Port().httpport,
-        'syslog_port':CreateTestPort.Port().syslogPort,
+        'agentDeployIp': ip.date().getAentHostIp,
+        'http_port': CreateTestPort.Port().httpport,
+        'syslog_port': CreateTestPort.Port().syslogPort,
         'FutureTime': ParaDateFiledServer().getFutureTime,
         'RoleId_user': DataManage.DataManage_Storage().RoleId_user,
-        'mailUser':testMail.date().getMailUser,
-        'mailPass':testMail.date().getMailPass,
-        'm_id':arPort.inputs().createarPortId
+        'mailUser': testMail.date().getMailUser,
+        'mailPass': testMail.date().getMailPass,
+        'm_id': arPort.inputs().createarPortId
     }
 
     switcher = SERVICE_KPI_
